from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

_74xGxx = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'74AHC1G4210', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G4210'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'divider oscillator', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC1G4210.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G4210\n\ndivider oscillator', 'pins':[
            Pin(num='1',name='X1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='X2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G74', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G74'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single D Flip-Flop D CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G74\n\nSingle D Flip-Flop D CMOS', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{CLR}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{PRE}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBT1G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBT1G125'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single FET Bus Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74CBT1G125\n\nSingle FET Bus Switch', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='B',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBT1G384', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBT1G384'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single FET Bus Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74CBT1G384\n\nSingle FET Bus Switch', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G00'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate NAND LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g00.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G00\n\nSingle Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G02'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate NOR LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g02.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G02\n\nSingle Gate NOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G04'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g04.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G06'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS Open Drain', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G06\n\nSingle Gate NOT LVC CMOS Open Drain', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G07'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate Buff LVC CMOS Open Drain', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g07.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G07\n\nSingle Gate Buff LVC CMOS Open Drain', 'pins':[
            Pin(num='1',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G08'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate AND LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g08.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G08\n\nSingle Gate AND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G0832', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G0832'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate AND-OR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G0832\n\nSingle Gate AND-OR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G10', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G10'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate NAND triple LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G10\n\nSingle Gate NAND triple LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G11', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G11'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate AND triple LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G11\n\nSingle Gate AND triple LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G123', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G123'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Mono Multivibrator CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1g123.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G123\n\nSingle Mono Multivibrator CMOS', 'pins':[
            Pin(num='1',name='~{A}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{CLR}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Cext',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='RCext',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '7', '5', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC1G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G125'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g125.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G125\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G126', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G126'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G126\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G139', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G139'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Decoder LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G139\n\nSingle Decoder LVC CMOS', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='Y3',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G14'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate NOT Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G14\n\nSingle Gate NOT Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G17', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G17'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate Buff Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g17.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G17\n\nSingle Gate Buff Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G175', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G175'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single D Flip-Flop Clear CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G175\n\nSingle D Flip-Flop Clear CMOS', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{CLR}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G18'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Demux LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G18\n\nSingle Demux LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '6', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74LVC1G19', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G19'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Decoder LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G19\n\nSingle Decoder LVC CMOS', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Y0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G240'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate Buff/Drv Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G240\n\nSingle Gate Buff/Drv Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G27', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G27'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate NOR triple LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G27\n\nSingle Gate NOR triple LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G29', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G29'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Decoder LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G29\n\nSingle Decoder LVC CMOS', 'pins':[
            Pin(num='1',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='A2',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Y2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y0',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G3157', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G3157'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'SPDT Analog Switch CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G3157\n\nSPDT Analog Switch CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '3', '6', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '5']}] }),
        Part(**{ 'name':'74LVC1G32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G32'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate OR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G32\n\nSingle Gate OR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G3208', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G3208'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate OR-AND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G3208\n\nSingle Gate OR-AND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G332', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G332'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate OR triple LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G332\n\nSingle Gate OR triple LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G34', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G34'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate Buff LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g34.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G34\n\nSingle Gate Buff LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G373', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G373'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single D Latch CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G373\n\nSingle D Latch CMOS', 'pins':[
            Pin(num='1',name='LE',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{OE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G374', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G374'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single D Flip-Flop Tri-State CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G374\n\nSingle D Flip-Flop Tri-State CMOS', 'pins':[
            Pin(num='1',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Q',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{OE}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G38'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate NAND Open Drain LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G38\n\nSingle Gate NAND Open Drain LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G386', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G386'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate XOR triple LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G386\n\nSingle Gate XOR triple LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G57', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G57'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G57\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G58', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G58'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G58\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Y}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G66', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G66'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Bilateral Analog Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1g66.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G66\n\nSingle Bilateral Analog Switch', 'pins':[
            Pin(num='1',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'74LVC1G79', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G79'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single D Flip-Flop D CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G79\n\nSingle D Flip-Flop D CMOS', 'pins':[
            Pin(num='1',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G80'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single D Flip-Flop CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G80\n\nSingle D Flip-Flop CMOS', 'pins':[
            Pin(num='1',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G86'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Gate XOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G86\n\nSingle Gate XOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G99', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G99'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/gpn/sn74lvc1g99', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G99\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1GU04DRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1GU04DRL'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-553'], 'footprint':'Package_TO_SOT_SMD:SOT-553', 'keywords':'inverter cmos', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1gu04.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1GU04DRL\n\ninverter cmos', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC2G00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G00'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate NAND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G00\n\nDual Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC2G02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G02'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate NOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G02\n\nDual Gate NOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'74LVC2G04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G04'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G04\n\nDual Gate NOT LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74LVC2G06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G06'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate NOT Open Drain LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G06\n\nDual Gate NOT Open Drain LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['2', '5']}] }),
        Part(**{ 'name':'74LVC2G07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G07'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate Buffer Open Drain LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G07\n\nDual Gate Buffer Open Drain LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74LVC2G08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G08'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate AND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G08\n\nDual Gate AND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '6', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC2G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G125'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G125\n\nDual Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'74LVC2G126', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G126'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G126\n\nDual Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC2G14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G14'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate NOT Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc2g14.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G14\n\nDual Gate NOT Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74LVC2G157', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G157'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single Mux CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G157\n\nSingle Mux CMOS', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{Y}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{A}/B',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{G}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC2G17', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G17'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Buffer Schmitt LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G17\n\nDual Buffer Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['2', '5']}] }),
        Part(**{ 'name':'74LVC2G240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G240'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Inv Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G240\n\nDual Inv Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC2G241', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G241'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G241\n\nDual Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'74LVC2G32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G32'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate OR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G32\n\nDual Gate OR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'74LVC2G34', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G34'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Buffer LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G34\n\nDual Buffer LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74LVC2G38', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G38'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate NAND Open Drain LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G38\n\nDual Gate NAND Open Drain LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC2G53', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G53'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Analog Switch 1 to 2 CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G53\n\nAnalog Switch 1 to 2 CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=2),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '2', '1', '5', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '3', '4']}] }),
        Part(**{ 'name':'74LVC2G66', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G66'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Analog Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G66\n\nDual Analog Switch', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '6', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC2G74', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G74'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Single D Flip-Flop D CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G74\n\nSingle D Flip-Flop D CMOS', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{CLR}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{PRE}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC2G79', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G79'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual D Flip-Flop D CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G79\n\nDual D Flip-Flop D CMOS', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC2G80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G80'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual D Flip-Flop Negative CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G80\n\nDual D Flip-Flop Negative CMOS', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '6', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC2G86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2G86'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Dual Gate XOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2G86\n\nDual Gate XOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '3', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC3G04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC3G04'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Triple Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC3G04\n\nTriple Gate NOT LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC3G06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC3G06'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Triple Gate NOT Open Drain LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC3G06\n\nTriple Gate NOT Open Drain LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='5',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '3']},{'label': 'uD', 'num': 4, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC3G07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC3G07'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Triple Buff Open Drain LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC3G07\n\nTriple Buff Open Drain LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='5',name='~',func=pin_types.OPENCOLL,unit=3),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC3G14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC3G14'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Triple NOT Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc3g14.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC3G14\n\nTriple NOT Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74LVC3G17', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC3G17'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Triple Buf Schmitt LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC3G17\n\nTriple Buf Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '3']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'74LVC3G34', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC3G34'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Triple Buf LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC3G34\n\nTriple Buf LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'Inverter_Schmitt_Dual', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Inverter_Schmitt_Dual'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'dual schmitt inverter', 'description':'', 'datasheet':'~', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nInverter_Schmitt_Dual\n\ndual schmitt inverter', 'pins':[
            Pin(num='1',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='2Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='1Y',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC7SVU04P5X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC7SVU04P5X'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-353_SC-70-5', 'keywords':'inverter', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/NC7SVU04-D.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nNC7SVU04P5X\n\ninverter', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NC7SZ125M5X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC7SZ125M5X'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'buffer three-state', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/nc7sz125-d.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nNC7SZ125M5X\n\nbuffer three-state', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1G00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G00'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate NAND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G00\n\nSingle Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1G02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G02'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate NOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G02\n\nSingle Gate NOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1G04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G04'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1G08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G08'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate AND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G08\n\nSingle Gate AND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G125'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G125\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1G126', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G126'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G126\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1G14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G14'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate NOT Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g14.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G14\n\nSingle Gate NOT Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1G32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G32'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate OR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G32\n\nSingle Gate OR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1G86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1G86'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate XOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1G86\n\nSingle Gate XOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC1GU04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC1GU04'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC1GU04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHC2G00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHC2G00'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Gate NAND LVC CMOS', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT2G00.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHC2G00\n\nDual Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AHCT1G00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1G00'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate NAND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1G00\n\nSingle Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT1G02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1G02'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate NOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1G02\n\nSingle Gate NOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT1G04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1G04'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1G04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT1G08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1G08'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate AND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1G08\n\nSingle Gate AND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT1G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1G125'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1G125\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT1G126', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1G126'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1G126\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT1G14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1G14'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate NOT Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1G14\n\nSingle Gate NOT Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT1G32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1G32'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate OR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1G32\n\nSingle Gate OR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT1G86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1G86'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate XOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1G86\n\nSingle Gate XOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT1GU04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT1GU04'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT1GU04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AHCT2G00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AHCT2G00'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Dual Gate NAND LVC CMOS', 'description':'', 'datasheet':'https://assets.nexperia.com/documents/data-sheet/74AHC_AHCT2G00.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AHCT2G00\n\nDual Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AUC1G00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G00'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single Gate NAND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G00\n\nSingle Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G02'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G02\n\nSingle Gate NOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G04'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G06'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS Open Drain', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G06\n\nSingle Gate NOT LVC CMOS Open Drain', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G07'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate Buff LVC CMOS Open Drain', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G07\n\nSingle Gate Buff LVC CMOS Open Drain', 'pins':[
            Pin(num='1',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G08'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single Gate AND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G08\n\nSingle Gate AND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G125'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G125\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G126', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G126'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G126\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G14'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOT Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G14\n\nSingle Gate NOT Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G17', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G17'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate Buff Schmitt LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G17\n\nSingle Gate Buff Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G18', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G18'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Demux LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G18\n\nSingle Demux LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '1', '6', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74AUC1G19', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G19'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Decoder LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G19\n\nSingle Decoder LVC CMOS', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~{E}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Y1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='Y0',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G240'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate Buff/Drv Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G240\n\nSingle Gate Buff/Drv Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G32'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single Gate OR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G32\n\nSingle Gate OR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G66', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G66'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Bilateral Analog Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74auc1g66.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G66\n\nSingle Bilateral Analog Switch', 'pins':[
            Pin(num='1',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '5']}] }),
        Part(**{ 'name':'74AUC1G79', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G79'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single D Flip-Flop D CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G79\n\nSingle D Flip-Flop D CMOS', 'pins':[
            Pin(num='1',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G80'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single D Flip-Flop CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G80\n\nSingle D Flip-Flop CMOS', 'pins':[
            Pin(num='1',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1G86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1G86'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single Gate XOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1G86\n\nSingle Gate XOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC1GU04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC1GU04'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC1GU04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUC2G00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G00'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Dual Gate NAND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G00\n\nDual Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AUC2G02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G02'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Gate NOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G02\n\nDual Gate NOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AUC2G04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G04'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G04\n\nDual Gate NOT LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74AUC2G06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G06'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Gate NOT Open Drain LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G06\n\nDual Gate NOT Open Drain LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74AUC2G07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G07'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Gate Buffer Open Drain LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G07\n\nDual Gate Buffer Open Drain LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74AUC2G08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G08'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Gate AND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G08\n\nDual Gate AND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '3', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AUC2G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G125'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G125\n\nDual Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'74AUC2G126', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G126'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G126\n\nDual Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'74AUC2G240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G240'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Inv Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G240\n\nDual Inv Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '7', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'74AUC2G241', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G241'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G241\n\nDual Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '7', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AUC2G32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G32'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Gate OR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G32\n\nDual Gate OR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '6', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AUC2G34', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G34'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Buffer LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G34\n\nDual Buffer LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74AUC2G53', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G53'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Analog Switch 1 to 2 CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G53\n\nAnalog Switch 1 to 2 CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=2),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1', '6', '2', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['8', '3', '4']}] }),
        Part(**{ 'name':'74AUC2G66', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G66'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Analog Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G66\n\nDual Analog Switch', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='7',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.TRISTATE,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AUC2G79', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G79'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual D Flip-Flop D CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G79\n\nDual D Flip-Flop D CMOS', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Q',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AUC2G80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G80'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual D Flip-Flop Negative CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G80\n\nDual D Flip-Flop Negative CMOS', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~{Q}',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='C',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '2', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '3', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'74AUC2G86', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2G86'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Dual Gate XOR LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2G86\n\nDual Gate XOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='5',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '1', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '3', '5']},{'label': 'uC', 'num': 3, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'74AUC2GU04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUC2GU04'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Dual Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUC2GU04\n\nDual Gate NOT LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['2', '5']}] }),
        Part(**{ 'name':'74AUP1G00', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G00'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate NAND LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74aup1g00.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G00\n\nSingle Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G02', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G02'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOR LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74aup1g02.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G02\n\nSingle Gate NOR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G04'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74aup1g04.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G06', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G06'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS Open Drain', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G06\n\nSingle Gate NOT LVC CMOS Open Drain', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G07', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G07'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate Buff LVC CMOS Open Drain', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74aup1g07', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G07\n\nSingle Gate Buff LVC CMOS Open Drain', 'pins':[
            Pin(num='1',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G08'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate AND LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74aup1g08.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G08\n\nSingle Gate AND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G125'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G125\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G126', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G126'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G126\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G14', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G14'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOT Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G14\n\nSingle Gate NOT Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G17', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G17'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate Buff Schmitt LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G17\n\nSingle Gate Buff Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G240', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G240'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single Gate Buff/Drv Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G240\n\nSingle Gate Buff/Drv Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G32', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G32'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate OR LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74aup1g32.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G32\n\nSingle Gate OR LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G34', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G34'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single Gate Buff LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74aup1g34.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G34\n\nSingle Gate Buff LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.FREE,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G57', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G57'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G57\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G58', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G58'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G58\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Y}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G74', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G74'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single D Flip-Flop D CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G74\n\nSingle D Flip-Flop D CMOS', 'pins':[
            Pin(num='1',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~{CLR}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~{PRE}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G79', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G79'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single D Flip-Flop D CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G79\n\nSingle D Flip-Flop D CMOS', 'pins':[
            Pin(num='1',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Q',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G80', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G80'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single D Flip-Flop CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G80\n\nSingle D Flip-Flop CMOS', 'pins':[
            Pin(num='1',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{Q}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G97', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G97'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G97\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G98', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G98'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G98\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Y}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1G99', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1G99'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1G99\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='B',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='C',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='D',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74AUP1GU04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74AUP1GU04'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74AUP1GU04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CB3T1G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CB3T1G125'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single FET Bus Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74CB3T1G125\n\nSingle FET Bus Switch', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='B',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBTD1G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTD1G125'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'Single FET Bus Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74CBTD1G125\n\nSingle FET Bus Switch', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='B',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBTD1G384', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTD1G384'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Single FET Bus Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74CBTD1G384\n\nSingle FET Bus Switch', 'pins':[
            Pin(num='1',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='B',func=pin_types.TRISTATE,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74CBTLV1G125', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74CBTLV1G125'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Single FET Bus Switch', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74CBTLV1G125\n\nSingle FET Bus Switch', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='B',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G97', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G97'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G97\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1G98', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1G98'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Configurable Single Gate LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1G98\n\nConfigurable Single Gate LVC CMOS', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{Y}',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='IN2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC1GU04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC1GU04'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', '', '', '', '', ''], 'footprint':'', 'keywords':'Single Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC1GU04\n\nSingle Gate NOT LVC CMOS', 'pins':[
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'74LVC2GU04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC2GU04'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'Dual Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC2GU04\n\nDual Gate NOT LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['3', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'74LVC3GU04', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'74LVC3GU04'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Triple Gate NOT LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/sg/scyt129e/scyt129e.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\n74LVC3GU04\n\nTriple Gate NOT LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='~',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='~',func=pin_types.INPUT,unit=3),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=4),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '5']},{'label': 'uD', 'num': 4, 'pin_nums': ['8', '4']}] }),
        Part(**{ 'name':'NC7SZ125P5X', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NC7SZ125P5X'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-353_SC-70-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'buffer three-state', 'description':'', 'datasheet':'https://www.onsemi.com/pdf/datasheet/nc7sz125-d.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nNC7SZ125P5X\n\nbuffer three-state', 'pins':[
            Pin(num='1',name='~{OE}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='A',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1G00DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1G00DBV'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'', 'keywords':'Single Gate NAND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1g00.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nSN74LVC1G00DBV\n\nSingle Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1G00DCK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1G00DCK'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:Texas_R-PDSO-G5_DCK-5'], 'footprint':'', 'keywords':'Single Gate NAND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1g00.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nSN74LVC1G00DCK\n\nSingle Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1G00DRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1G00DRL'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:Texas_R-PDSO-G5_DCK-5', 'Package_TO_SOT_SMD:Texas_R-PDSO-N5_DRL-5'], 'footprint':'', 'keywords':'Single Gate NAND LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1g00.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nSN74LVC1G00DRL\n\nSingle Gate NAND LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1G125DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1G125DBV'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1g125.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nSN74LVC1G125DBV\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1G125DCK', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1G125DCK'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:Texas_R-PDSO-G5_DCK-5'], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1g125.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nSN74LVC1G125DCK\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1G125DRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1G125DRL'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:Texas_R-PDSO-G5_DCK-5', 'Package_TO_SOT_SMD:Texas_R-PDSO-N5_DRL-5'], 'footprint':'', 'keywords':'Single Gate Buff Tri-State LVC CMOS', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/sn74lvc1g125.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nSN74LVC1G125DRL\n\nSingle Gate Buff Tri-State LVC CMOS', 'pins':[
            Pin(num='1',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.TRISTATE,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1G14DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1G14DBV'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', 'Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'', 'keywords':'Single Gate NOT Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g14.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nSN74LVC1G14DBV\n\nSingle Gate NOT Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC1G14DRL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC1G14DRL'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', 'Package_TO_SOT_SMD:SOT-23-5', 'Package_TO_SOT_SMD:SOT-553'], 'footprint':'', 'keywords':'Single Gate NOT Schmitt LVC CMOS', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc1g14.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nSN74LVC1G14DRL\n\nSingle Gate NOT Schmitt LVC CMOS', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN74LVC2G14DBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN74LVC2G14DBV'}), 'ref_prefix':'U', 'fplist':['', 'Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'', 'keywords':'dual schmitt inverter', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/sn74lvc2g14.pdf', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nSN74LVC2G14DBV\n\ndual schmitt inverter', 'pins':[
            Pin(num='1',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='2Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='1Y',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TC7PZ14FU', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TC7PZ14FU'}), 'ref_prefix':'U', 'fplist':['', 'Package_TO_SOT_SMD:SOT-23-6', 'Package_TO_SOT_SMD:SOT-363_SC-70-6'], 'footprint':'', 'keywords':'dual schmitt inverter', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/docget.jsp?did=14431&prodName=TC7PZ14FU', 'search_text':'/usr/share/kicad/symbols/74xGxx.kicad_sym\nTC7PZ14FU\n\ndual schmitt inverter', 'pins':[
            Pin(num='1',name='1A',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='2A',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='2Y',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V_{CC}',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='1Y',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] })])